searchData={"items":[{"type":"module","title":"ExXendit","doc":"Handles base http requests","ref":"ExXendit.html"},{"type":"type","title":"ExXendit.sub_account_id/0","doc":"The id of the sub-account.","ref":"ExXendit.html#t:sub_account_id/0"},{"type":"module","title":"ExXendit.Transaction","doc":"Handles functions at https://developers.xendit.co/api-reference/#transactions","ref":"ExXendit.Transaction.html"},{"type":"function","title":"ExXendit.Transaction.get/2","doc":"","ref":"ExXendit.Transaction.html#get/2"},{"type":"function","title":"ExXendit.Transaction.list/2","doc":"List the transactions of your main or sub-account. Use `list/1` if you intend to use for main only.","ref":"ExXendit.Transaction.html#list/2"},{"type":"function","title":"Request Parameters - ExXendit.Transaction.list/2","doc":"* `:types` - The type of the transactions that will be filtered. If not specified, all transaction type will be returned. \n\n    Available types:\n    - DISBURSEMENT: The disbursement of money-out transaction.\n    - PAYMENT: The payment that includes all variation of money-in transaction.\n    - REMITTANCE_PAYOUT: The remittance pay-out transaction.\n    - TRANSFER: The transfer transaction between xendit account. This can be transfer in or out.\n    - REFUND: A refund transaction created to refund amount from money-in Transaction.\n\n  * `:statuses` - The status of the transactions that will be filtered. If not specified, all transaction status will be returned. \n    \n    Available status:\n    - PENDING: The transaction is still pending to be processed. This refers to money out-transaction when the amount is still on hold.\n    - SUCCESS: The transaction is successfully sent for money-out or already arrives on money-in.\n    - FAILED: The transaction failed to send/receive.\n    - VOIDED: The money-in transaction is voided by customer.\n    - REVERSED: The transaction is reversed by Xendit.\n\n  * `:channel_categories` - The channel of the transactions that will be filtered. If not specified, all transaction channel will be returned.\n\n    For DISBURSEMENT and REMITTANCE_PAYOUT type, the available channel categories are BANK and CASH.\n    For PAYMENT type, the available channel categories are CARDS, CARDLESS_CREDIT, DIRECT_DEBIT, EWALLET, PAYLATER, QR_CODE, RETAIL_OUTLET, VIRTUAL_ACCOUNT.\n    For TRANSFER type, the available channel category is XENPLATFORM.\n\n  * `:reference_id` - Reference that will be searched. Search by reference is case sensitive and can be partial match.\n\n  * `:product_id` - Product_id that will be searched. Product_id search is an exact match and case sensitive.\n\n  * `:account_identifier` - Account identifier that will be searched. Account identifier search is exact match case sensitive.\n\n  * `:currency` - Currency to filter. \n\n    Ex. `PHP`, `IDR`, `USD`, `VND`, `THB`, `MYR`, Default: `IDR`\n\n  * `:amount` - Transaction amount to search. This will be exact match. \n\n  * `:created_gte` - Start time of transaction by created date. If not specified will list all dates. \n\n  * `:created_lte` - End time of transaction by created date. If not specified will list all dates. \n\n  * `:updated_gte` - Start time of transaction by updated date. If not specified will list all dates. \n\n  * `:updated_lte` - End time of transaction by updated date. If not specified will list all dates. \n\n  * `:limit` - A limit on the number of transactions to be returned for each request. Default: `10`\n\n  * `:after_id` - Id of the immediately previous item. Use this with links on the response for pagination.\n\n  * `:before_id` - Id of the immediately following item.","ref":"ExXendit.Transaction.html#list/2-request-parameters"},{"type":"function","title":"Response Parameters - ExXendit.Transaction.list/2","doc":"* `:data` - Returns an array of Transaction Object. Returns empty array when there is no result \n\n  * `:has_more` - Indicates whether there are more items to be queried with after_id of the last item from the current result.\n    Use the links to follow to the next result. \n\n  * `:links` - The links to the next page based on HATEOAS if there is next result.\n\n    The HATEOAS format are:\n    `href`: URI of target, this will be to the next link.\n    `rel`: The relationship between source and target. The value will be next.\n    `method`: The HTTP method, the alue will be GET.","ref":"ExXendit.Transaction.html#list/2-response-parameters"},{"type":"function","title":"Examples - ExXendit.Transaction.list/2","doc":"# Main Account\n    iex> ExXendit.Transaction.list(%{currency: \"PHP\"})\n    {:ok, %Req.Response{}}\n\n    # Sub Account\n    iex> ExXendit.Transaction.list(%{currency: \"PHP\"}, \" \")\n    {:ok, %Req.Response{}}","ref":"ExXendit.Transaction.html#list/2-examples"},{"type":"extras","title":"ExXendit","doc":"# ExXendit\n[![License](https://img.shields.io/hexpm/l/req.svg)](https://github.com/wojtekmach/req/blob/main/LICENSE.md)\n[![Version](https://img.shields.io/hexpm/v/req.svg)](https://hex.pm/packages/req)\n[![CI](https://github.com/wojtekmach/req/actions/workflows/ci.yml/badge.svg)](https://github.com/wojtekmach/req/actions/workflows/ci.yml)\n\n[Docs](https://hexdocs.pm/ex_xendit)\n\nExXendit is an elixir sdk for [Xendit](https://www.xendit.com).","ref":"readme.html"},{"type":"extras","title":"Installation - ExXendit","doc":"Put this in your `mix.exs` and run `mix deps.get`.\n\n```elixir\ndef deps do\n  [\n    {:ex_xendit, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ExXendit","doc":"Before you use, you need to have credentials in Xendit. Check guide [here](https://developers.xendit.co/api-reference/#authentication).\n\nOnce done, add your credentials inside your configs. \n\n```\nconfig :ex_xendit,\n  base_url: \"https://api.xendit.co\",\n  secret_key: \"REPLACE WITH YOUR SECRET KEY\",\n  public_key: \"REPLACE WITH YOUR PUBLIC KEY\"\n```","ref":"readme.html#usage"},{"type":"extras","title":"Developers - ExXendit","doc":"To contribute to this project:\n\n- Fork this project and clone in your machine\n- Copy `config.secret.backup.exs` to `config.secret.exs` then set your credentials\n- Look for new updates at [Xendit API Docs](https://developers.xendit.co/api-reference/)\n- Follow code pattern \n\nBefore you submit pull request:\n\n- Run `mix coveralls`. Be sure coverage is at 100%\n- Run `mix credo`. Be sure everything is clean.\n- Run `mix dialyzer`. Be sure everything is good.","ref":"readme.html#developers"},{"type":"extras","title":"License - ExXendit","doc":"Copyright (c) 2023 Noel Del Castillo\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at \n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 (2023-11-16) - CHANGELOG","doc":"- Develop `ExXendit.Transaction.get`\n- Develop `ExXendit.Transaction.list`\n- Initial release","ref":"changelog.html#v0-1-0-2023-11-16"}],"content_type":"text/markdown"}